import { __awaiter, __decorate, __generator, __metadata } from "tslib";
import { inject, singleton } from 'mana-syringe';
import { Shape, RenderingPluginContribution, RenderingContext, ElementEvent, isString } from '@antv/g';
import { ImagePool } from './shapes/ImagePool';

var LoadImagePlugin =
/** @class */
function () {
  function LoadImagePlugin() {}

  LoadImagePlugin_1 = LoadImagePlugin;

  LoadImagePlugin.prototype.apply = function (renderingService) {
    var _this = this;

    var handleMounted = function handleMounted(e) {
      var object = e.target;
      var nodeName = object.nodeName,
          attributes = object.attributes;

      if (nodeName === Shape.IMAGE) {
        var img = attributes.img;

        if (isString(img)) {
          _this.imagePool.getOrCreateImage(img).then(function () {
            // set dirty rectangle flag
            object.renderable.dirty = true;
            renderingService.dirtify();
          });
        }
      }
    };

    var handleAttributeChanged = function handleAttributeChanged(e) {
      var object = e.target;
      var attrName = e.attrName,
          newValue = e.newValue;

      if (object.nodeName === Shape.IMAGE) {
        if (attrName === 'img') {
          if (isString(newValue)) {
            _this.imagePool.getOrCreateImage(newValue).then(function () {
              // set dirty rectangle flag
              object.renderable.dirty = true;
              renderingService.dirtify();
            });
          }
        }
      }
    };

    renderingService.hooks.init.tapPromise(LoadImagePlugin_1.tag, function () {
      return __awaiter(_this, void 0, void 0, function () {
        return __generator(this, function (_a) {
          this.renderingContext.root.addEventListener(ElementEvent.MOUNTED, handleMounted);
          this.renderingContext.root.addEventListener(ElementEvent.ATTR_MODIFIED, handleAttributeChanged);
          return [2
          /*return*/
          ];
        });
      });
    });
    renderingService.hooks.destroy.tap(LoadImagePlugin_1.tag, function () {
      _this.renderingContext.root.removeEventListener(ElementEvent.MOUNTED, handleMounted);

      _this.renderingContext.root.removeEventListener(ElementEvent.ATTR_MODIFIED, handleAttributeChanged);
    });
  };

  var LoadImagePlugin_1;
  LoadImagePlugin.tag = 'LoadImage';

  __decorate([inject(ImagePool), __metadata("design:type", ImagePool)], LoadImagePlugin.prototype, "imagePool", void 0);

  __decorate([inject(RenderingContext), __metadata("design:type", Object)], LoadImagePlugin.prototype, "renderingContext", void 0);

  LoadImagePlugin = LoadImagePlugin_1 = __decorate([singleton({
    contrib: RenderingPluginContribution
  })], LoadImagePlugin);
  return LoadImagePlugin;
}();

export { LoadImagePlugin };