import { Shape } from '@antv/g';
import { Module, GlobalContainer } from 'mana-syringe';
import RBush from 'rbush';
import { CircleRenderer, CircleRendererContribution, EllipseRenderer, EllipseRendererContribution, ImageRendererContribution, LineRenderer, LineRendererContribution, PathRenderer, PathRendererContribution, PolygonRenderer, PolygonRendererContribution, PolylineRenderer, PolylineRendererContribution, RectRenderer, RectRendererContribution, StyleRendererFactory, TextRendererContribution } from './shapes/styles';
import { ImageRenderer } from './shapes/styles/Image';
import { GradientPool } from './shapes/GradientPool';
import { ImagePool } from './shapes/ImagePool';
import { PathGeneratorFactory, PathGenerator, CirclePath, EllipsePath, RectPath, LinePath, PolylinePath, PolygonPath, PathPath } from './shapes/paths';
import { TextRenderer } from './shapes/styles/Text';
import { CanvasRendererPlugin, RBushRoot } from './CanvasRendererPlugin';
import { LoadImagePlugin } from './LoadImagePlugin';
import { RBushNode } from './components/RBushNode';
export { PathGeneratorFactory, PathGenerator, RBushNode, RBushRoot, RBush };
export * from './shapes/styles';
/**
 * register shape renderers
 */

GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.CIRCLE
  },
  useValue: CirclePath
});
GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.ELLIPSE
  },
  useValue: EllipsePath
});
GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.RECT
  },
  useValue: RectPath
});
GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.LINE
  },
  useValue: LinePath
});
GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.POLYLINE
  },
  useValue: PolylinePath
});
GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.POLYGON
  },
  useValue: PolygonPath
});
GlobalContainer.register({
  token: {
    token: PathGenerator,
    named: Shape.PATH
  },
  useValue: PathPath
});
GlobalContainer.register({
  token: PathGeneratorFactory,
  useFactory: function useFactory(ctx) {
    var cache = {};
    return function (tagName) {
      if (!cache[tagName]) {
        if (ctx.container.isBoundNamed(PathGenerator, tagName)) {
          cache[tagName] = ctx.container.getNamed(PathGenerator, tagName);
        }
      }

      return cache[tagName];
    };
  }
});
var containerModule = Module(function (register) {
  var _a;

  register(ImagePool);
  register({
    token: RBushRoot,
    useValue: new RBush()
  });
  register(CircleRenderer);
  register(EllipseRenderer);
  register(RectRenderer);
  register(ImageRenderer);
  register(TextRenderer);
  register(LineRenderer);
  register(PolylineRenderer);
  register(PolygonRenderer);
  register(PathRenderer);
  var shape2Token = (_a = {}, _a[Shape.CIRCLE] = CircleRendererContribution, _a[Shape.ELLIPSE] = EllipseRendererContribution, _a[Shape.RECT] = RectRendererContribution, _a[Shape.IMAGE] = ImageRendererContribution, _a[Shape.TEXT] = TextRendererContribution, _a[Shape.LINE] = LineRendererContribution, _a[Shape.POLYLINE] = PolylineRendererContribution, _a[Shape.POLYGON] = PolygonRendererContribution, _a[Shape.PATH] = PathRendererContribution, _a);
  register({
    token: StyleRendererFactory,
    useFactory: function useFactory(ctx) {
      var cache = {};
      return function (tagName) {
        var token = shape2Token[tagName];

        if (token && !cache[tagName]) {
          if (ctx.container.isBound(token)) {
            cache[tagName] = ctx.container.get(token);
          }
        }

        return cache[tagName];
      };
    }
  });
  register(GradientPool);
  register(CanvasRendererPlugin);
  register(LoadImagePlugin);
});

var Plugin =
/** @class */
function () {
  function Plugin() {}

  Plugin.prototype.init = function (container) {
    container.load(containerModule, true);
  };

  Plugin.prototype.destroy = function (container) {
    container.unload(containerModule);
  };

  return Plugin;
}();

export { Plugin };