"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LoadImagePlugin = void 0;

var _tslib = require("tslib");

var _manaSyringe = require("mana-syringe");

var _g = require("@antv/g");

var _ImagePool = require("./shapes/ImagePool");

var LoadImagePlugin =
/** @class */
function () {
  function LoadImagePlugin() {}

  LoadImagePlugin_1 = LoadImagePlugin;

  LoadImagePlugin.prototype.apply = function (renderingService) {
    var _this = this;

    var handleMounted = function handleMounted(e) {
      var object = e.target;
      var nodeName = object.nodeName,
          attributes = object.attributes;

      if (nodeName === _g.Shape.IMAGE) {
        var img = attributes.img;

        if ((0, _g.isString)(img)) {
          _this.imagePool.getOrCreateImage(img).then(function () {
            // set dirty rectangle flag
            object.renderable.dirty = true;
            renderingService.dirtify();
          });
        }
      }
    };

    var handleAttributeChanged = function handleAttributeChanged(e) {
      var object = e.target;
      var attrName = e.attrName,
          newValue = e.newValue;

      if (object.nodeName === _g.Shape.IMAGE) {
        if (attrName === 'img') {
          if ((0, _g.isString)(newValue)) {
            _this.imagePool.getOrCreateImage(newValue).then(function () {
              // set dirty rectangle flag
              object.renderable.dirty = true;
              renderingService.dirtify();
            });
          }
        }
      }
    };

    renderingService.hooks.init.tapPromise(LoadImagePlugin_1.tag, function () {
      return (0, _tslib.__awaiter)(_this, void 0, void 0, function () {
        return (0, _tslib.__generator)(this, function (_a) {
          this.renderingContext.root.addEventListener(_g.ElementEvent.MOUNTED, handleMounted);
          this.renderingContext.root.addEventListener(_g.ElementEvent.ATTR_MODIFIED, handleAttributeChanged);
          return [2
          /*return*/
          ];
        });
      });
    });
    renderingService.hooks.destroy.tap(LoadImagePlugin_1.tag, function () {
      _this.renderingContext.root.removeEventListener(_g.ElementEvent.MOUNTED, handleMounted);

      _this.renderingContext.root.removeEventListener(_g.ElementEvent.ATTR_MODIFIED, handleAttributeChanged);
    });
  };

  var LoadImagePlugin_1;
  LoadImagePlugin.tag = 'LoadImage';
  (0, _tslib.__decorate)([(0, _manaSyringe.inject)(_ImagePool.ImagePool), (0, _tslib.__metadata)("design:type", _ImagePool.ImagePool)], LoadImagePlugin.prototype, "imagePool", void 0);
  (0, _tslib.__decorate)([(0, _manaSyringe.inject)(_g.RenderingContext), (0, _tslib.__metadata)("design:type", Object)], LoadImagePlugin.prototype, "renderingContext", void 0);
  LoadImagePlugin = LoadImagePlugin_1 = (0, _tslib.__decorate)([(0, _manaSyringe.singleton)({
    contrib: _g.RenderingPluginContribution
  })], LoadImagePlugin);
  return LoadImagePlugin;
}();

exports.LoadImagePlugin = LoadImagePlugin;