"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  Plugin: true,
  RBush: true,
  PathGeneratorFactory: true,
  PathGenerator: true,
  RBushRoot: true,
  RBushNode: true
};
Object.defineProperty(exports, "PathGenerator", {
  enumerable: true,
  get: function get() {
    return _paths.PathGenerator;
  }
});
Object.defineProperty(exports, "PathGeneratorFactory", {
  enumerable: true,
  get: function get() {
    return _paths.PathGeneratorFactory;
  }
});
exports.Plugin = void 0;
Object.defineProperty(exports, "RBush", {
  enumerable: true,
  get: function get() {
    return _rbush.default;
  }
});
Object.defineProperty(exports, "RBushNode", {
  enumerable: true,
  get: function get() {
    return _RBushNode.RBushNode;
  }
});
Object.defineProperty(exports, "RBushRoot", {
  enumerable: true,
  get: function get() {
    return _CanvasRendererPlugin.RBushRoot;
  }
});

var _g = require("@antv/g");

var _manaSyringe = require("mana-syringe");

var _rbush = _interopRequireDefault(require("rbush"));

var _styles = require("./shapes/styles");

Object.keys(_styles).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _styles[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _styles[key];
    }
  });
});

var _Image = require("./shapes/styles/Image");

var _GradientPool = require("./shapes/GradientPool");

var _ImagePool = require("./shapes/ImagePool");

var _paths = require("./shapes/paths");

var _Text = require("./shapes/styles/Text");

var _CanvasRendererPlugin = require("./CanvasRendererPlugin");

var _LoadImagePlugin = require("./LoadImagePlugin");

var _RBushNode = require("./components/RBushNode");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * register shape renderers
 */
_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.CIRCLE
  },
  useValue: _paths.CirclePath
});

_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.ELLIPSE
  },
  useValue: _paths.EllipsePath
});

_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.RECT
  },
  useValue: _paths.RectPath
});

_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.LINE
  },
  useValue: _paths.LinePath
});

_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.POLYLINE
  },
  useValue: _paths.PolylinePath
});

_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.POLYGON
  },
  useValue: _paths.PolygonPath
});

_manaSyringe.GlobalContainer.register({
  token: {
    token: _paths.PathGenerator,
    named: _g.Shape.PATH
  },
  useValue: _paths.PathPath
});

_manaSyringe.GlobalContainer.register({
  token: _paths.PathGeneratorFactory,
  useFactory: function useFactory(ctx) {
    var cache = {};
    return function (tagName) {
      if (!cache[tagName]) {
        if (ctx.container.isBoundNamed(_paths.PathGenerator, tagName)) {
          cache[tagName] = ctx.container.getNamed(_paths.PathGenerator, tagName);
        }
      }

      return cache[tagName];
    };
  }
});

var containerModule = (0, _manaSyringe.Module)(function (register) {
  var _a;

  register(_ImagePool.ImagePool);
  register({
    token: _CanvasRendererPlugin.RBushRoot,
    useValue: new _rbush.default()
  });
  register(_styles.CircleRenderer);
  register(_styles.EllipseRenderer);
  register(_styles.RectRenderer);
  register(_Image.ImageRenderer);
  register(_Text.TextRenderer);
  register(_styles.LineRenderer);
  register(_styles.PolylineRenderer);
  register(_styles.PolygonRenderer);
  register(_styles.PathRenderer);
  var shape2Token = (_a = {}, _a[_g.Shape.CIRCLE] = _styles.CircleRendererContribution, _a[_g.Shape.ELLIPSE] = _styles.EllipseRendererContribution, _a[_g.Shape.RECT] = _styles.RectRendererContribution, _a[_g.Shape.IMAGE] = _styles.ImageRendererContribution, _a[_g.Shape.TEXT] = _styles.TextRendererContribution, _a[_g.Shape.LINE] = _styles.LineRendererContribution, _a[_g.Shape.POLYLINE] = _styles.PolylineRendererContribution, _a[_g.Shape.POLYGON] = _styles.PolygonRendererContribution, _a[_g.Shape.PATH] = _styles.PathRendererContribution, _a);
  register({
    token: _styles.StyleRendererFactory,
    useFactory: function useFactory(ctx) {
      var cache = {};
      return function (tagName) {
        var token = shape2Token[tagName];

        if (token && !cache[tagName]) {
          if (ctx.container.isBound(token)) {
            cache[tagName] = ctx.container.get(token);
          }
        }

        return cache[tagName];
      };
    }
  });
  register(_GradientPool.GradientPool);
  register(_CanvasRendererPlugin.CanvasRendererPlugin);
  register(_LoadImagePlugin.LoadImagePlugin);
});

var Plugin =
/** @class */
function () {
  function Plugin() {}

  Plugin.prototype.init = function (container) {
    container.load(containerModule, true);
  };

  Plugin.prototype.destroy = function (container) {
    container.unload(containerModule);
  };

  return Plugin;
}();

exports.Plugin = Plugin;